Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(41)

Unified Diff: src/compiler/verifier.cc

Issue 2828573004: [turbofan] Fix typing rule for JSCreateArguments. (Closed)
Patch Set: Also fix the verifier. Created 3 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « src/compiler/types.h ('k') | test/mjsunit/regress/regress-crbug-712802.js » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: src/compiler/verifier.cc
diff --git a/src/compiler/verifier.cc b/src/compiler/verifier.cc
index 9fdb37c3051c5e0beb31e5bdd2a4d322fb434e35..2ba9ebbe0b13cb6d0cf717b7edfc910da791cc59 100644
--- a/src/compiler/verifier.cc
+++ b/src/compiler/verifier.cc
@@ -598,8 +598,8 @@ void Verifier::Visitor::Check(Node* node) {
CheckTypeIs(node, Type::Object());
break;
case IrOpcode::kJSCreateArguments:
- // Type is OtherObject.
- CheckTypeIs(node, Type::OtherObject());
+ // Type is Array \/ OtherObject.
+ CheckTypeIs(node, Type::ArrayOrOtherObject());
break;
case IrOpcode::kJSCreateArray:
// Type is Array.
« no previous file with comments | « src/compiler/types.h ('k') | test/mjsunit/regress/regress-crbug-712802.js » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698